#
# spec file for package Herwig
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define so_name Herwig-libs
Name:           Herwig
Version:        7.1.2
Release:        lp150.2.1
Summary:        Multi-purpose event generator for high-energy physics
License:        GPL-2.0-only
Group:          Development/Libraries/C and C++
Url:            http://herwig.hepforge.org/
Source0:        http://www.hepforge.org/archive/herwig/%{name}-%{version}.tar.bz2
Source1:        %{name}-rpmlintrc
# PATCH-FIX-OPENSUSE Herwig-disable-repo-install.patch badshah400@gmail.com -- Disable post-install hooks intended to set up the Herwig repo, this doesn't work inside the build script because of missing LHAPDF data that needs to be installed by the user; the install-hook doesn't serve any purpose while building the rpm and users can easily set this up on their own
Patch0:         Herwig-disable-repo-install.patch
BuildRequires:  HepMC2-devel
BuildRequires:  LHAPDF-devel
BuildRequires:  Rivet-devel
BuildRequires:  ThePEG-devel >= 2.0.4
%if 0%{?suse_version} > 1320
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_headers-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_test-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  fastjet-devel
BuildRequires:  fastjet-plugin-siscone-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python-devel
BuildRequires:  pkgconfig(gsl)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  x86_64

%description
Herwig is a multi-purpose particle physics event generator.
Herwig 7.0 (Herwig++ 3.0) replaces any prior HERWIG or Herwig++ versions.

Herwig features coherent parton showers (including angular-ordered
and dipole-based evolution), the cluster hadronization model, an
eikonal multiple-interaction model, highly flexible BSM capabilities
and improved perturbative input using next-to-leading order QCD.

Herwig is based on ThePEG.

%package -n %{so_name}
Summary:        Multi purpose event generator for high energy physics
Group:          System/Libraries
Obsoletes:      libHerWig1 < %{version}-%{release}
Provides:       libHerWig1 = %{version}-%{release}

%description -n %{so_name}
Herwig is a multi-purpose particle physics event generator.

Herwig features coherent parton showers (including angular-ordered
and dipole-based evolution), the cluster hadronization model, an
eikonal multiple-interaction model, highly flexible BSM capabilities
and improved perturbative input using next-to-leading order QCD.

Herwig is based on ThePEG.

This package provides the shared libraries for %{name}.

%package devel
Summary:        Multi purpose event generator for high energy physics
Group:          Development/Libraries/C and C++
Requires:       %{so_name} = %{version}
Requires:       ThePEG-devel
Provides:       Herwig++-devel = %{version}
Obsoletes:      Herwig++-devel < %{version}

%description devel
Herwig is a multi-purpose particle physics event generator.
Herwig 7.0 (Herwig++ 3.0) replaces any prior HERWIG or Herwig++ versions.

Herwig features coherent parton showers (including angular-ordered
and dipole-based evolution), the cluster hadronization model, an
eikonal multiple-interaction model, highly flexible BSM capabilities
and improved perturbative input using next-to-leading order QCD.

Herwig is based on ThePEG.

This package provides the header and source libraries for development
with %{name}.

%prep
%setup -q
%patch0 -p1

%build
autoreconf -fvi
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install

mkdir -p %{buildroot}/%{_sysconfdir}/ld.so.conf.d
echo %{_libdir}/%{name} > %{buildroot}/%{_sysconfdir}/ld.so.conf.d/%{name}.conf

find %{buildroot} -type f -name "*.la" -delete -print

# Remove unnecessary hashbangs
sed -i "1{/\/usr\/bin\/env/d;}" %{buildroot}%{_libdir}/%{name}/python/slha2herwig
sed -i "1{/\/usr\/bin\/env/d;}" %{buildroot}%{_libdir}/%{name}/python/ufo2herwig

# Fix hashbangs to directly point to python
for exe in gosam2herwig herwig-mergegrids mg2herwig slha2herwig ufo2herwig
do 
 sed -i "1{s/\/usr\/bin\/env python/\/usr\/bin\/python/;}" %{buildroot}%{_bindir}/${exe}
done

%fdupes -s %{buildroot}%{_libdir}/%{name}/

%post -n %{so_name} -p /sbin/ldconfig
%postun -n %{so_name} -p /sbin/ldconfig

%files -n %{so_name}
%defattr(-,root,root)
%doc AUTHORS GUIDELINES ChangeLog README COPYING
%config %{_sysconfdir}/ld.so.conf.d/%{name}.conf
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*.so.*

%files devel
%defattr(-,root,root)
%{_bindir}/Herwig
%{_bindir}/herwig-combinedistributions
%{_bindir}/herwig-combineruns
%{_bindir}/herwig-makedistributions
%{_bindir}/herwig-mergegrids
%{_bindir}/herwig-config
%{_bindir}/ufo2herwig
%{_bindir}/slha2herwig
%{_bindir}/gosam2herwig
%{_bindir}/mg2herwig
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*.so
%{_libdir}/%{name}/python/
%{_includedir}/%{name}/
%{_datadir}/%{name}/

%changelog
* Thu Apr 19 2018 guillaume.gardet@opensuse.org
- Build Herwig only on x86_64 since other archs are not supported
* Sun Nov  5 2017 badshah400@gmail.com
- Update to version 7.1.2:
  * Reduction of the default pt cut for QED radiation off leptons.
  * Inputfile changes due to new read mode in ThePEG.  ThePEG
    remains in current repo dir when reading input-file/snippet.
  * Fix for shower scale variations in qtilde shower.
  * All standard input files now use the tuned intrinsic pt.
  * Remove obsolete input files for various tunes.
  * Fix for Madgraph interface for NLO corrections with recent
    version.
  * Run file size reduction for processes using madgraph/openloops.
  * Fix in jacobian for massive dipole kinematics.
  * General improvements for UFO model handling.
- Fix env based hashbangs (/usr/bin/env python -> /usr/bin/python,
  etc.).
* Wed Oct 11 2017 badshah400@gmail.com
- Use more fine-grained BuildRequires on boost* libraries for
  openSUSE > 1320.
* Sat Sep  2 2017 badshah400@gmail.com
- Build with HepMC2-devel, since Rivet does not compile with
  HepMC-devel >= 3 yet.
* Wed Aug  2 2017 badshah400@gmail.com
- Update to version 7.1.1:
  * Snippets are now all installed
  * Fixed broken ufo2herwig output and LHC-MB.in
  * UFO improvements
  - More robust SLHA file handling
  - option of creating diagonal mixing matrices, needed for
    ATLAS simplfied models
  - Improved warnings about resetting standard model particles
  - Fixed certain cases where the wrong lorentz structure was
    picked in VVS vertices
  * Improved error message for unhandled beam particles
  * Fix for Dipole Shower chain selection
  * Fixed crash in double diffractive delta resonances
- Changes from version 7.1.0:
  * For a more detailed overview and further references please see
    the release note arXiv:1705.06919
  * NLO multijet merging with the dipole shower
  * A new soft model
  * An interface to EvtGen
  * Improved calculation of mass effects in the dipole shower
  * Top decays in the dipole shower, and NLO corrections to the
    decay
  * An implementation of the KrkNLO method for simple processes
  * Major restructuring and cleanup of default input files
  * C++11 is now mandatory and heavily used in the code
  * Many smaller bugfixes and improvements
- Update filelist for new and dropped binaries.
- Disable for %%{ix86}: no longer supported.
- Rebase Herwig-disable-repo-install.patch for update.
* Mon Feb 13 2017 jengelh@inai.de
- Rename from libHerWig1 to Herwig-libs as the package does not
  satisfy the SLPP guideline: there are a number of non-.so.1
  files.
* Wed Nov 16 2016 jengelh@inai.de
- Trim history lesson from description
* Tue Nov 15 2016 badshah400@gmail.com
- Rename shared library, adding the so number from
  libHerwigAPI.so; the so numbers of the other shared libraries
  are expected to be incremented by upstream in step with this.
- Move config file to -devel pkg in keeping with shlib packaging
  policy.
- Added obsoletes/provides for Herwig++ which will now be dropped
  from Factory.
* Fri Nov 11 2016 badshah400@gmail.com
- Initial package.
- Add Herwig-disable-repo-install.patch: Disable post-install
  hooks intended to set up the Herwig repo, this doesn't work
  inside the build script because of missing LHAPDF data that
  needs to be installed by the user; the install-hook doesn't
  serve any purpose while building the rpm and users can easily
  set this up on their own.
